Update of /var/cvs/src/org/mmbase/module/core
In directory james.mmbase.org:/tmp/cvs-serv4998

Modified Files:
        MMObjectBuilder.java 
Log Message:
made getDescendants unmodifiable. Related to MMB-1684


See also: http://cvs.mmbase.org/viewcvs/src/org/mmbase/module/core
See also: http://www.mmbase.org/jira/browse/MMB-1684


Index: MMObjectBuilder.java
===================================================================
RCS file: /var/cvs/src/org/mmbase/module/core/MMObjectBuilder.java,v
retrieving revision 1.426
retrieving revision 1.427
diff -u -b -r1.426 -r1.427
--- MMObjectBuilder.java        10 Jun 2008 12:03:11 -0000      1.426
+++ MMObjectBuilder.java        18 Jul 2008 04:17:35 -0000      1.427
@@ -61,7 +61,7 @@
  * @author Rob van Maris
  * @author Michiel Meeuwissen
  * @author Ernst Bunders
- * @version $Id: MMObjectBuilder.java,v 1.426 2008/06/10 12:03:11 michiel Exp $
+ * @version $Id: MMObjectBuilder.java,v 1.427 2008/07/18 04:17:35 michiel Exp $
  */
 public class MMObjectBuilder extends MMTable implements NodeEventListener, 
RelationEventListener {
 
@@ -703,7 +703,7 @@
     }
 
     /**
      * Creates list of descendant-builders.
      *
      * @since MMBase-1.6.2
      */
@@ -720,9 +720,9 @@
                 // I don't quite know why
                 descendants = result;
             }
-            return result;
+            return Collections.unmodifiableList(result);
         }
-        return descendants;
+        return Collections.unmodifiableList(descendants);
     }
 
     /**
@@ -703,7 +703,7 @@
 
     /**
-     * Creates list of descendant-builders.
+     * Returns an (unmodifiable) list of all descendant-builders.
      *
      * @since MMBase-1.6.2
_______________________________________________
Cvs mailing list
Cvs@lists.mmbase.org
http://lists.mmbase.org/mailman/listinfo/cvs

Reply via email to